unit EanQr;

interface
uses SysUtils,EanKod,QrCtrls,Classes,Graphics,Messages,
     Controls;

type
  TQrCustomEan = class(TQrShape)
     private
         procedure   SetBarCode(Value:String);
         procedure   SetShowLabels(Value:Boolean);
         procedure   SetTransparent(Value:Boolean);
         procedure   SetStartStopLines(Value:Boolean);
         procedure   SetLinesColor(Value:TColor);
         procedure   SetBackgroundColor(Value:TColor);
         procedure   SetSecurity(Value:Boolean);
         procedure   SetDemoVersion(Value:Boolean);
         procedure   SetEan13AddUp(Value:Boolean);
         procedure   SetFontAutoSize(Value:Boolean);
         Function    GetBarCode       :String;
         Function    GetShowLabels    :Boolean;
         Function    GetTransparent   :Boolean;
         Function    GetStartStopLines:Boolean;
         Function    GetLinesColor    :TColor;
         Function    GetBackgroundColor :TColor;
         Function    GetEan13AddUp      :Boolean;
         Function    GetFontAutoSize    :Boolean;
         Function    GetSecurity        :Boolean;
         Function    GetDemoVersion     :Boolean;
         Function    GetTypBarCode      :TTypBarCode;
         Function    GetLAstPaintError  :TLastPaintError;
     protected
            FEan : TCustomEan;
            constructor Create(AOwner:TComponent); override;
            destructor  Destroy;                   override;
            procedure   Paint; override;
            procedure   SetTypBarCode(Value:TTypBarCode);   virtual;
            property    DemoVersion : Boolean Read GetDemoVersion Write SetDemoVersion;
     public
         procedure  Next;
         function   GetSetOfChars:string;
         function   GetSetOfCharsVisible:String;
         function   CheckBarCode(var S:String):Boolean;
         procedure  Print(X,Y:Integer);  override;
         function   LastPaintErrorText:String;
         property BackgroundColor   : TColor         Read GetBackgroundColor Write SetBackgroundColor;
         property Transparent       : Boolean        Read GetTransparent     Write SetTransparent;
         property ShowLabels        : Boolean        Read GetShowLabels      Write SetShowLabels;
         property StartStopLines    : Boolean        Read GetStartStopLines  Write SetStartStopLines;
         property TypBarCode        : TTypBarCode    Read GetTypBarCode      Write SetTypBarCode;
         property LinesColor        : TColor         Read GetLinesColor      Write SetLinesColor;
         property Ean13AddUp        : Boolean        Read GetEan13AddUp      Write SetEan13AddUp;
         property FontAutoSize      : Boolean        Read GetFontAutoSize    Write SetFontAutoSize;
         property Security          : Boolean        Read GetSecurity        Write SetSecurity;
         property Font;
         property BarCode           : string         Read GetBarCode         Write SetBarCode;
         property LastPaintError :TLastPaintError    Read GetLastPaintError;
     published
     end;

  TQrEan   = class(TQrCustomEan)
     published
         property BackgroundColor;
         property Transparent;
         property ShowLabels;
         property StartStopLines;
         property TypBarCode;
         property LinesColor;
         property Ean13AddUp;
         property FontAutoSize;
         property Security;
         property DemoVersion;
         property Font;
         property LastPaintError;
         property BarCode;
  end;



  TQrEanMemo   = class(TQrCustomEan)
     private
         procedure   SetTypBarCode(Value:TTypBarCode); override;
     protected
         function  GetLines:TStringList;
         procedure SetLines(Value:TStringList);
     public
         constructor Create(AOwner: TComponent); override;
         destructor Destroy; override;
     published
         property Lines:TStringList Read GetLines Write SetLines;
         property BackgroundColor;
         property Transparent;
         property ShowLabels;
         property StartStopLines;
         property TypBarCode;
         property LinesColor;
         property Ean13AddUp;
         property FontAutoSize;
         property Security;
         property DemoVersion;
         property Font;
         property LastPaintError;
         property BarCode;
     end;


implementation
uses Windows;

constructor TQrCustomEan.Create(AOwner:TComponent);
var i:Integer;
begin
     inherited Create(AOwner);
     FEan          := TEan.Create(self);
     FEan.Security := False;
     i:=FEan.MinWidth;
     if Width<i then Width:=i;
end;

destructor  TQrCustomEan.Destroy;
begin
     inherited Destroy;
end;


procedure   TQrCustomEan.SetBarCode(Value:String);
begin
     if FEan.BarCode<>Value then begin
        FEan.BarCode:=Value;
        Invalidate;
     end;
end;

procedure   TQrCustomEan.SetShowLabels(Value:Boolean);
begin
     if FEan.ShowLabels<>Value then begin
        FEan.ShowLabels:=Value;
        Invalidate;
     end;
end;

procedure   TQrCustomEan.SetTransparent(Value:Boolean);
begin
     if FEan.Transparent<>Value then begin
        FEan.Transparent:=Value;
        Invalidate;
     end;
end;

procedure   TQrCustomEan.SetStartStopLines(Value:Boolean);
begin
     if FEan.StartStopLines<>Value then begin
        FEan.StartStopLines:=Value;
        Invalidate;
     end;
end;

procedure   TQrCustomEan.SetLinesColor(Value:TColor);
begin
     if FEan.LinesColor<>Value then begin
        FEan.LinesColor:=Value;
        Invalidate;
     end;
end;

procedure   TQrCustomEan.SetBackgroundColor(Value:TColor);
begin
     if FEan.BackgroundColor<>Value then begin
        FEan.BackgroundColor:=Value;
        Invalidate;
     end;
end;

procedure   TQrCustomEan.SetEan13AddUp(Value:Boolean);
begin
     if FEan.Ean13AddUp<>Value then begin
        FEan.Ean13AddUp:=Value;
        Invalidate;
     end;
end;

procedure   TQrCustomEan.SetFontAutoSize(Value:Boolean);
begin
     if FEan.FontAutoSize<>Value then begin
        FEan.FontAutoSize:=Value;
        Invalidate;
     end;
end;

procedure   TQrCustomEan.SetSecurity(Value:Boolean);
begin
     if FEan.Security<>Value then begin
        FEan.Security:=Value;
        Invalidate;
     end;
end;

procedure   TQrCustomEan.SetDemoVersion(Value:Boolean);
begin
     if FEan.DemoVersion<>Value then begin
        FEan.DemoVersion:=Value;
        Invalidate;
     end;
end;


procedure   TQrCustomEan.SetTypBarCode(Value:TTypBarCode);
var i:Integer;
begin
     if FEan.TypBarCode<>Value then begin
        FEan.TypBarCode:=Value;
        i:=fEan.MinWidth;
        if Width<i then Width := i;
        Invalidate;
     end;
end;


Function    TQrCustomEan.GetBarCode       :String;
begin
     Result:=FEan.BarCode;
end;

Function    TQrCustomEan.GetShowLabels    :Boolean;
begin
     Result:=FEan.ShowLabels;
end;

Function    TQrCustomEan.GetTransparent   :Boolean;
begin
     Result:=FEan.Transparent;
end;

Function    TQrCustomEan.GetStartStopLines:Boolean;
begin
     Result:=FEan.StartStopLines;
end;

Function    TQrCustomEan.GetLinesColor    :TColor;
begin
     Result:=FEan.LinesColor;
end;

Function    TQrCustomEan.GetBackgroundColor :TColor;
begin
     Result:=FEan.BackgroundColor;
end;

Function    TQrCustomEan.GetEan13AddUp      :Boolean;
begin
     Result:=FEan.Ean13AddUp;
end;

Function    TQrCustomEan.GetFontAutoSize  :Boolean;
begin
     Result:=FEan.FontAutoSize;
end;

Function    TQrCustomEan.GetSecurity        :Boolean;
begin
     Result:=FEan.Security;
end;

Function    TQrCustomEan.GetDemoVersion:Boolean;
begin
     Result:=FEan.DemoVersion;
end;

Function    TQrCustomEan.GetTypBarCode      :TTypBarCode;
begin
     Result:=fEan.TypBarCode;
end;


Function    TQrCustomEan.GetLastPaintError  :TLastPaintError;
begin
     Result:=fEan.LastPaintError;
end;


procedure TQrCustomEan.Paint;
begin
     PaintBarCode(Canvas,Rect(0,0,Width,Height),FEan);
end;


procedure TQrCustomEan.Next;
begin
     FEan.Next;
end;

function   TQrCustomEan.GetSetOfChars:string;
begin
     Result:=FEan.GetSetOfChars;
end;

function   TQrCustomEan.GetSetOfCharsVisible:String;
begin
     Result:=FEan.GetSetOfCharsVisible;
end;

function   TQrCustomEan.CheckBarCode(var S:String):Boolean;
begin
     Result:=FEan.CheckBarCode(S);
end;

procedure  TQrCustomEan.Print(X,Y:Integer);
var R:TRect;
begin
     R.Left   := QRPrinter.XPos(Size.Left+X);
     R.Top    := QRPrinter.YPos(Size.Top+Y);
     R.Right  := R.Left+QRPrinter.XSize(Size.Width);
     R.Bottom := R.Top+QRPrinter.YSize(Size.Height);

     PaintBarCode(QRPrinter.Canvas,R,FEan);
end;

function   TQrCustomEan.LastPaintErrorText:String;
begin
     Result:=FEan.LastPaintErrorText;
end;


constructor TQrEanMemo.Create(AOwner: TComponent);
begin
     inherited Create(AOwner);
     FEan.Free;
     FEan:=TEanMemo.Create(Self);
     ShowLabels     := False;
     StartStopLines := False;
end;

Destructor TQrEanMemo.Destroy;
begin
     inherited Destroy;
end;

procedure TQrEanMemo.SetLines(Value:TStringList);
begin
    TEanMemo(FEan).Lines.Assign(Value);
    Invalidate;
end;

procedure   TQrEanMemo.SetTypBarCode(Value:TTypBarCode);
begin
     if FEan.TypBarCode<>Value then begin
        inherited SetTypBarCode(Value);
        TEanMemo(FEan).Lines.Clear;
        TEanMemo(FEan).Lines.Add(BarCode);
     end;
end;

function TQrEanMemo.GetLines:TStringList;
begin
     Result:=TEanMemo(FEan).Lines;
end;




end.
